function varargout=slicemesh(self,P,varargin)
% FUNCTION slicemesh 
%   Plots the intersection of the plane defined by
%         P(1)*x+P(2)*y+P(3)*z+P(4)=0
%   and the siMesh object.
%
% USAGE
%   Th.slicemesh(P) or slicemesh(Th,P) where 
%     Th is a siMesh object,
%     P  is a vector which contains the coefficients of the plane.
%
%   Th.slicemesh(P,key,value,...) allows additional key/value pairs to be 
%     used when displaying the siMesh object. The key strings could be
%
%     'labels' to specify the labels of the elementary meshes. 
%              Default [] i.e all.
%     'color'  to specify the color of the displayed plane. Default is 
%              0.9*[1 1 1] (gray). 
%              If value is [] then the plane is colored with the colors 
%              of the intersected siMeshElt objects.
%
% SAMPLES
%   Th=fc_simesh.HyperCube(3,10);
%   P=fc_tools.graphics.PlaneCoefs(0.5*[1 1 1],[1 -1 1]);
%   figure(1)
%   Th.slicemesh(P)
%   hold on
%   Th.plot('d',1,'color','k')
%   figure(2)
%   Th.slicemesh(P,'edgecolor','k','color',[])
%
%    <COPYRIGHT>
  assert(self.d==3 && self.dim==3);
  p = inputParser; 
  p.KeepUnmatched=true; 
  p.PartialMatching=false;
  p.addParamValue('labels',[]); % select labels to draw
  p.addParamValue('color',0.9*[1 1 1]);
  p.parse(varargin{:});
  R=p.Results;
  varargin=fc_tools.utils.deleteCellOptions(varargin,p.Parameters);
  if ~isempty(R.color), varargin={varargin{:},'FaceColor',R.color};end
  if isempty(R.labels), idxlab=self.find(3);else idxlab=self.find(3,R.labels);end
  if isempty(idxlab), return;end

  PrevHold=fc_tools.graphics.SetHoldOn(true);
  if ~PrevHold, clf;hold on;end
  for ilab=[idxlab]
      self.sTh{ilab}.slicemesh(P,varargin{:});%,'PlotOptions',R.PlotOptions);
  end
  fc_tools.graphics.RestoreHold(PrevHold)
end
